api.pdns.v3 package — Argus-Toolbelt 1.0 documentation

# api.pdns.v3 package

## Subpackages

- api.pdns.v3.test_helpers package
  - Subpackages
    - api.pdns.v3.test_helpers.search package
      - Submodules
      - api.pdns.v3.test_helpers.search.search_records module
      - Module contents
  - Submodules
  - api.pdns.v3.test_helpers.search_records_simplified module
  - Module contents

## Submodules

## api.pdns.v3.search module

Autogenerated API

`api.pdns.v3.search.` `search_records`(query: str = None, rrClass: list = None, rrType: list = None, customerID: list = None, tlp: list = None, limit: int = None, aggregateResult: bool = 'False', includeAnonymousResults: bool = 'False', offset: int = 0, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search against PassiveDNS with criteria and return matching records (PUBLIC) Search against PassiveDNS with criteria and return matching records. If user exceeds current resource limits, this operation may return status code 402. If that happens, the metaData key millisUntilResourcesAvailable gives a hint as to how long the client needs to wait before attempting again.

  Return type: | `dict`

## Module contents